package com.example.studentinfo;

import android.content.Intent;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.Adapter;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.Toast;

import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;

import com.example.studentinfo.mysqllist.MySQLiteOpenHelper;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class searchActivity extends AppCompatActivity implements View.OnClickListener {

    /*
    query(table, columns, selection, selectionArgs, groupBy, having, orderBy, limit)方法各参数的含义：
    table 需要查询表名
    columns 需要查询的字段,全部查询就写null,部分就写new String[]{"id","name","sex"}
    selection 查询条件,where后的条件语句,不带内容 例如:id>? and name=?
    selectionArgs 查询条件对于的内容 例如:{"10","xiaoming"}
    groupBy 分组
    having 分组的过滤条件
    orderBy 排序,例如 "id asc"(desc-降序 asc-升序)
    limit 查询显示的条数(分页,可以不写,默认全部显示,
    例如"100"(前100条数据),
    也可以只取 前4条，例如"0,4"（从第1条数据开始取，取4条数据，下标从0开始）。
    例如"3,4"(从第4条数据开始取，取4条数据))
     */
    private String tableName = "";
    private Button mBtExit;
    private Button mBtAdd;
    private EditText mEtSearch;
    private Button mBtnSearch;
    private ListView mListInfo;
    private MySQLiteOpenHelper mDbHelper;
    private SQLiteDatabase mSQLiteDatabase;
    private final String DB_NAME = "Student.db";

    private ArrayAdapter<String> mArrayAdapter;
    private List<String> mDataList = new ArrayList<>();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_search);
        initView();
        initData();
    }

    private void initData() {
        mDbHelper = new MySQLiteOpenHelper(this, DB_NAME, null, 1);
        mSQLiteDatabase = mDbHelper.getWritableDatabase();
        queryAll();


    }


    //查询所有数据
    private void queryAll() {
        String content = "";
        Cursor cursor = mSQLiteDatabase.query("user", null, null, null, null, null, null);
        cursor.getCount();
        content+=" 数据库总共有"+cursor.getCount()+"记录\n";
        Toast.makeText(this,content,Toast.LENGTH_LONG).show();
        if (cursor!=null) {
            mDataList.clear();
            while (cursor.moveToNext()) {
                String strName = cursor.getString(cursor.getColumnIndex("name"));
                int iNumber = cursor.getInt(cursor.getColumnIndex("id"));
                String strCls = cursor.getString(cursor.getColumnIndex("cls"));
                String misboy = cursor.getString(cursor.getColumnIndex("isboy"));
                mDataList.add(strName+'\n'+iNumber);
            }
//            mArrayAdapter.notifyDataSetChanged();
            mArrayAdapter=new ArrayAdapter<>(this,android.R.layout.simple_list_item_1,mDataList);
            mListInfo.setAdapter(mArrayAdapter);

        }else {
            Toast.makeText(this,"空",Toast.LENGTH_LONG).show();
        }
        if (cursor!=null){
            cursor.close();
        }
    }

    //根据要求查询数据
    private void query() {
        String text=mEtSearch.getText().toString().trim();
        if(TextUtils.isEmpty(text)){
            return;

        }
        Cursor cursor = mSQLiteDatabase.query("user", null,"name=? or id=?", new String[]{text,text},null,null,null);
        if(cursor.moveToFirst())
        {
            do {
                String strName = cursor.getString(cursor.getColumnIndex("name"));
                int iNumber = cursor.getInt(cursor.getColumnIndex("id"));
                String strCls = cursor.getString(cursor.getColumnIndex("cls"));
                String misboy = cursor.getString(cursor.getColumnIndex("isboy"));
                mDataList.clear();
                mDataList.add(strName+'\n'+iNumber);
                mArrayAdapter=new ArrayAdapter<>(this,android.R.layout.simple_list_item_1,mDataList);
                mListInfo.setAdapter(mArrayAdapter);
                Toast.makeText(this, " 查询成功", Toast.LENGTH_SHORT).show();
                return ;
            }while (cursor.moveToNext());
        }
        Toast.makeText(this, " 查询失败", Toast.LENGTH_SHORT).show();
        return ;

    }




    private void initView() {
        mBtExit = (Button) findViewById(R.id.bt_exit);
        mBtAdd = (Button) findViewById(R.id.bt_add);
        mEtSearch = (EditText) findViewById(R.id.et_search);
        mBtnSearch = (Button) findViewById(R.id.btn_search);
        mListInfo = (ListView) findViewById(R.id.list_info);

        mBtExit.setOnClickListener(this);
        mBtAdd.setOnClickListener(this);
        mBtnSearch.setOnClickListener(this);

        mListInfo.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
//                        String num=mArrayAdapter.getItem(position);
                        String num=mArrayAdapter.getItem(position);
                        Intent intent =new Intent(searchActivity.this,detailActivity.class);
                        intent.putExtra("num",num);
                        startActivityForResult(intent,0);
                    }
                }
        );


    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.bt_exit:

                break;
            case R.id.bt_add:
                Intent intent =new Intent(searchActivity.this,AddDataActivity.class);
                startActivity(intent);

                break;
            case R.id.btn_search:
                String search=mEtSearch.getText().toString();
                if (TextUtils.isEmpty(search)){
                queryAll();
                }else {
                    query();
                }

                break;
        }
    }

    /**
     * Dispatch incoming result to the correct fragment.
     *
     * @param requestCode
     * @param resultCode
     * @param data
     */
    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        queryAll();
        mArrayAdapter.notifyDataSetChanged();
    }

    private void submit() {
        // validate
        String search = mBtnSearch.getText().toString().trim();
        if (TextUtils.isEmpty(search)) {
            Toast.makeText(this, "search不能为空", Toast.LENGTH_SHORT).show();
            return;
        }

        // TODO validate success, do something


    }
}
